@@ -1,7 +1,8 @@
 `demoChart` <-
-function(rows, columns) {
+function(rows, columns, use.letters=TRUE) {
+    splitmethod <- ifelse(use.letters, "", "\\*")
     mtrx <- t(sapply(rows, function(x) {
-        y <- unlist(strsplit(x, ""))
+        y <- unlist(strsplit(x, splitmethod))
         sapply(columns, function(idcol) {
             all(sapply(y, function(z) regexpr(z, idcol) > 0))
             })
